@@ -26,12 +26,11 @@
 
 G_BEGIN_DECLS
 
-GType ev_document_type_lookup (const char  *uri,
-			       gchar       **mime_type,
-			       GError      **error);
-
-void ev_document_types_add_filters	    (GtkWidget *chooser);
-void ev_document_types_add_filters_for_type (GtkWidget *chooser, GType type);
+EvDocument     *ev_document_types_get_document		(const char   *uri,
+			     	 			 gchar       **mime_type,
+			  			         GError      **error);
+void		ev_document_types_add_filters		(GtkWidget    *chooser,
+							 EvDocument   *document);
 
 G_END_DECLS
 
