@@ -59,9 +59,11 @@ void		ev_window_open_uri	  (EvWindow       *ev_window,
 void		ev_window_open_page_label (EvWindow       *ev_window,
 					   const char     *label);
 gboolean	ev_window_is_empty	  (const EvWindow *ev_window);
+#ifdef WITH_GNOME_PRINT
 void		ev_window_print_range     (EvWindow       *ev_window,
 					   int             first_page,
 					   int		   last_page);
+#endif
 G_END_DECLS
 
 #endif /* !EV_WINDOW_H */
